@@ -9,12 +9,14 @@ use std::{collections::HashSet, io::Write};
 #[derive(Debug)]
 pub struct Melter {
     on_failed_resolve: FailedResolveStrategy,
+    rewrite: bool,
 }
 
 impl Default for Melter {
     fn default() -> Self {
         Melter {
-            on_failed_resolve: FailedResolveStrategy::Stringify,
+            on_failed_resolve: FailedResolveStrategy::Ignore,
+            rewrite: true,
         }
     }
 }
@@ -31,6 +33,15 @@ impl Melter {
         self
     }
 
+    /// Set if the melter should rewrite properties to better match the plaintext format
+    ///
+    /// Setting to false will preserve binary fields and values even if they
+    /// don't make any sense in the plaintext output.
+    pub fn with_rewrite(mut self, rewrite: bool) -> Self {
+        self.rewrite = rewrite;
+        self
+    }
+
     fn convert(
         &self,
         input: &[u8],
@@ -61,7 +72,7 @@ impl Melter {
             match token {
                 BinaryToken::Object(_) => {
                     did_change = true;
-                    writer.extend_from_slice(b"{\r\n");
+                    writer.extend_from_slice(b"{\n");
                     depth += 1;
                     in_objects.push(in_object);
                     in_object = 1;
@@ -131,7 +142,7 @@ impl Melter {
                 BinaryToken::F32(x) => write!(writer, "{}", x).map_err(Hoi4ErrorKind::IoErr)?,
                 BinaryToken::F64(x) => write!(writer, "{}", x).map_err(Hoi4ErrorKind::IoErr)?,
                 BinaryToken::Token(x) => match TokenLookup.resolve(*x) {
-                    Some(id) if id == "is_ironman" && in_object == 1 => {
+                    Some(id) if self.rewrite && id == "is_ironman" && in_object == 1 => {
                         let skip = tokens
                             .get(token_idx + 1)
                             .map(|next_token| match next_token {
@@ -188,7 +199,6 @@ impl Melter {
                 in_object = 2;
             } else if in_object == 2 {
                 in_object = 1;
-                writer.push(b'\r');
                 writer.push(b'\n');
             } else if in_object != 1 {
                 writer.push(b' ');
@@ -204,7 +214,7 @@ impl Melter {
     /// with the gamestate data decoded from binary to plain text.
     pub fn melt(&self, mut data: &[u8]) -> Result<(Vec<u8>, HashSet<u16>), Hoi4Error> {
         let mut result = Vec::with_capacity(data.len());
-        result.extend_from_slice(b"HOI4txt\r\n");
+        result.extend_from_slice(b"HOI4txt\n");
         let header = b"HOI4bin";
         if data.get(..header.len()).map_or(false, |x| x == header) {
             data = &data[header.len()..];
